==> tecfy_core_package-0.0.4.tar.gz: lib/views/home/setting.dart <==
part of tecfy_core_client_package;

class SettingPage extends StatefulWidget {
  @override
  _SettingPageState createState() => _SettingPageState();
}

class _SettingPageState extends State<SettingPage> {

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: MainAppBar(
        context:context,
        title: AppLocale.translate(context, 'Settings'),
      ),
      backgroundColor: ThemeService.backgroundColor,
     // bottomNavigationBar: MainBottomNavigationBar(4,true),
      body: Column(
        children: <Widget>[
          SizedBox(height: 15.0),
          Card(
            margin: EdgeInsets.symmetric(horizontal: 15.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: <Widget>[
                Container(
                  height: 45.0,
                  color: ThemeService.background2Color,
                  child: Padding(padding: EdgeInsets.only(left: 10.0),child: Align(alignment: Alignment.centerLeft, child: Text(AppLocale.translate(context, 'Language'),style: Theme.of(context).textTheme.title,))),
                ),
                 //item('Account Information', ()=>AccountPage())
                 Container(
                  height: 70.0,
                  color: Colors.white,
                  margin: EdgeInsets.only(left: 10),
                  child: Align(alignment: Alignment.centerLeft, child:
                   DropdownButtonHideUnderline(child:  DropdownButton(
                   value: ConfigService.getValueInt(ConfigKeys.language),
                   items: [
                     DropdownMenuItem(child: Text('عربي'),value: Language.arabic.index),
                     DropdownMenuItem(child: Text('English'),value:Language.english.index)
                   ],
                   onChanged: (v)async{
                     ConfigService.setValueInt(ConfigKeys.language.index, v);
                    //  await ConfigService.saveConfig();
                     //TecfyMainApplication.restartApp(context);
                     SystemChannels.platform.invokeMethod('SystemNavigator.pop');
                     setState(() {});
                   },
                 ))))
              ],
            ),
          ),
          SizedBox(height: 15.0),
             Card(
            margin: EdgeInsets.symmetric(horizontal: 15.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: <Widget>[
                Container(
                  height: 45.0,
                  color: ThemeService.background2Color,
                  child: Padding(padding: EdgeInsets.only(left: 10.0),child: Align(alignment: Alignment.centerLeft, child: Text('Application',style: Theme.of(context).textTheme.title,))),
                ),
                 item('Terms & Conditions', null),//()=>WebViewPage('Terms & Conditions','https://wishooo.com/terms-and-conditions')),
                 divider(),
                 item('Privacy', null),//()=>WebViewPage('Privacy Policy','https://wishooo.com/privacy-policy')),
                 divider(),
                 item('FAQ\'s', null),//()=>WebViewPage('FAQ\'s','http://google.com')),
              ],
            ),
          ),
          Expanded(
            child: Container(),
          ),
           Row(
            children: <Widget>[
              SizedBox(width: 15.0),
              // Expanded(child:
              // getBoarder(FlatButton(
              //   onPressed: ()=>AccountService.deleteAccount(context),
              //   child: Text('Delete Account', style: TextStyle(color: ThemeService.mainColor, fontSize: 18.0)),
              // ))),
              // SizedBox(width: 15.0),
              Expanded(child:
               MaterialButton(
                height: 60.0,
                minWidth: double.infinity,
                color: ThemeService.mainColor,
                onPressed: ()=>AccountService.signout(context),
                child: Text(AppLocale.translate(context, 'Logout'), style: TextStyle(color: ThemeService.mainTextColor, fontSize: 18.0),),
              )),
              SizedBox(width: 15.0),
            ],
          ),
          SizedBox(height: 40.0)
        ],
      ),
    );
  }

   getBoarder(widget) {
    return Container(
        height: 60.0,
        decoration: BoxDecoration(
            border: Border.all(color: ThemeService.mainColor),
            borderRadius: BorderRadius.all(Radius.circular(2.0))),
        child: widget);
  }

  divider(){
    return Padding(
      padding: EdgeInsets.symmetric(horizontal: 10.0),
      child: Container(height: 1.0,color: ThemeService.background2Color));
  }
  item(title, creator){
    return GestureDetector(
      onTap: creator == null ? null : ()=>AppNavigator.navigateTo(context, creator),
      child: Container(
                  height: 70.0,
                  color: Colors.white,
                  child: Align(alignment: Alignment.centerLeft, child:
                  Row(
                    children: <Widget>[
                      SizedBox(width:10.0),
                      Expanded(child:  Text(title,style: Theme.of(context).textTheme.subtitle,)),
                      SizedBox(width:10.0),
                      Icon(Icons.arrow_right, color: Theme.of(context).textTheme.subtitle.color,),
                      SizedBox(width:10.0),
                    ],
                  )),
                ));
  }

  Future<String> getAppVersion() async{
    // PackageInfo packageInfo = await PackageInfo.fromPlatform();
    return '';//packageInfo.version;
  }
}

==> tecfy_core_package-0.1.3.tar.gz: lib/views/home/setting.dart <==
part of tecfy_core_client_package;

class SettingPage extends StatefulWidget {
  @override
  _SettingPageState createState() => _SettingPageState();
}

class _SettingPageState extends State<SettingPage> {

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: MainAppBar(
        context:context,
        title: AppLocale.translate(context, 'Settings'),
      ),
      backgroundColor: ThemeService.backgroundColor,
     // bottomNavigationBar: MainBottomNavigationBar(4,true),
      body: Column(
        children: <Widget>[
          SizedBox(height: 15.0),
          Card(
            margin: EdgeInsets.symmetric(horizontal: 15.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: <Widget>[
                Container(
                  height: 45.0,
                  color: ThemeService.background2Color,
                  child: Padding(padding: EdgeInsets.symmetric(horizontal: 10),child: Align(alignment: LocalConfigService.isArabic ? Alignment.centerRight :Alignment.centerLeft, child: Text(AppLocale.translate(context, 'Language'),style: Theme.of(context).textTheme.title,))),
                ),
                 //item('Account Information', ()=>AccountPage())
                 Container(
                  height: 70.0,
                  color: Colors.white,
                  margin: EdgeInsets.symmetric(horizontal: 10),
                  child: Align(alignment: LocalConfigService.isArabic ? Alignment.centerRight : Alignment.centerLeft, child:
                   DropdownButtonHideUnderline(child:  DropdownButton<Language>(
                   value: LocalConfigService.language,
                   items: [
                     //DropdownMenuItem(child: Text('N/A'),value: 0),
                     DropdownMenuItem(child: Text('عربي'),value: Language.arabic),
                     DropdownMenuItem(child: Text('English'),value:Language.english)
                   ],
                   onChanged: (v)async{
                     LocalConfigService.language = v;                     
                    //  await ConfigService.saveConfig();
                     //TecfyMainApplication.restartApp(context);
                     var result = await AppNavigator.confirmMessage(context, 'Do you want to restart the application to apply the changes?');
                     if(result){
                      SystemChannels.platform.invokeMethod('SystemNavigator.pop');
                     }
                      setState(() {});
                   },
                 ))))
              ],
            ),
          ),
          SizedBox(height: 15.0),
             Card(
            margin: EdgeInsets.symmetric(horizontal: 15.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: <Widget>[
                Container(
                  height: 45.0,
                  color: ThemeService.background2Color,
                  child: Padding(padding: EdgeInsets.only(left: 10.0),child: Align(alignment: Alignment.centerLeft, child: Text('Application',style: Theme.of(context).textTheme.title,))),
                ),
                 item('Terms & Conditions', null),//()=>WebViewPage('Terms & Conditions','https://wishooo.com/terms-and-conditions')),
                 divider(),
                 item('Privacy', null),//()=>WebViewPage('Privacy Policy','https://wishooo.com/privacy-policy')),
                 divider(),
                 item('FAQ\'s', null),//()=>WebViewPage('FAQ\'s','http://google.com')),
              ],
            ),
          ),
          Expanded(
            child: Container(),
          ),
           Row(
            children: <Widget>[
              SizedBox(width: 15.0),
              // Expanded(child:
              // getBoarder(FlatButton(
              //   onPressed: ()=>AccountService.deleteAccount(context),
              //   child: Text('Delete Account', style: TextStyle(color: ThemeService.mainColor, fontSize: 18.0)),
              // ))),
              // SizedBox(width: 15.0),
              Expanded(child:
               MaterialButton(
                height: 60.0,
                minWidth: double.infinity,
                color: ThemeService.mainColor,
                onPressed: ()=>AccountService.signout(context),
                child: Text(AppLocale.translate(context, 'Logout'), style: TextStyle(color: ThemeService.mainTextColor, fontSize: 18.0),),
              )),
              SizedBox(width: 15.0),
            ],
          ),
          SizedBox(height: 40.0)
        ],
      ),
    );
  }

   getBoarder(widget) {
    return Container(
        height: 60.0,
        decoration: BoxDecoration(
            border: Border.all(color: ThemeService.mainColor),
            borderRadius: BorderRadius.all(Radius.circular(2.0))),
        child: widget);
  }

  divider(){
    return Padding(
      padding: EdgeInsets.symmetric(horizontal: 10.0),
      child: Container(height: 1.0,color: ThemeService.background2Color));
  }
  item(title, creator){
    return GestureDetector(
      onTap: creator == null ? null : ()=>AppNavigator.navigateTo(context, creator),
      child: Container(
                  height: 70.0,
                  color: Colors.white,
                  child: Align(alignment: Alignment.centerLeft, child:
                  Row(
                    children: <Widget>[
                      SizedBox(width:10.0),
                      Expanded(child:  Text(title,style: Theme.of(context).textTheme.subtitle,)),
                      SizedBox(width:10.0),
                      Icon(Icons.arrow_right, color: Theme.of(context).textTheme.subtitle.color,),
                      SizedBox(width:10.0),
                    ],
                  )),
                ));
  }

  Future<String> getAppVersion() async{
    // PackageInfo packageInfo = await PackageInfo.fromPlatform();
    return '';//packageInfo.version;
  }
}
